"""
This module contains stroke shaders used for creation of stylized
strokes.  It is also intended to be a collection of examples for
shader definition in Python.

User-defined stroke shaders inherit the
freestyle.types.StrokeShader class.

"""

import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.types
import freestyle.types
import mathutils

class BackboneStretcherShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `BackboneStretcherShader`[Geometry shader]"""

    def __init__(self, amount: float = 2.0) -> None:
        """Builds a BackboneStretcherShader object.

        :param amount: The stretching amount value.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Stretches the stroke at its two extremities and following the
        respective directions: v(1)v(0) and v(n-1)v(n).

                :param stroke: A Stroke object.
        """

class BezierCurveShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `BezierCurveShader`[Geometry shader]"""

    def __init__(self, error: float = 4.0) -> None:
        """Builds a BezierCurveShader object.

                :param error: The error were allowing for the approximation. This
        error is the max distance allowed between the new curve and the
        original geometry.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Transforms the stroke backbone geometry so that it corresponds to a
        Bezier Curve approximation of the original backbone geometry.

                :param stroke: A Stroke object.
        """

class BlenderTextureShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `BlenderTextureShader`[Texture shader]"""

    def __init__(
        self, texture: bpy.types.LineStyleTextureSlot | bpy.types.ShaderNodeTree
    ) -> None:
        """Builds a BlenderTextureShader object.

        :param texture: A line style texture slot or a shader node tree to define a set of textures.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Assigns a blender texture slot to the stroke  shading in order to
        simulate marks.

                :param stroke: A Stroke object.
        """

class CalligraphicShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `CalligraphicShader`[Thickness Shader]"""

    def __init__(
        self,
        thickness_min: float,
        thickness_max: float,
        orientation: collections.abc.Sequence[float] | mathutils.Vector,
        clamp: bool,
    ) -> None:
        """Builds a CalligraphicShader object.

                :param thickness_min: The minimum thickness in the direction
        perpendicular to the main direction.
                :param thickness_max: The maximum thickness in the main direction.
                :param orientation: The 2D vector giving the main direction.
                :param clamp: If true, the strokes are drawn in black when the stroke
        direction is between -90 and 90 degrees with respect to the main
        direction and drawn in white otherwise. If false, the strokes
        are always drawn in black.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Assigns thicknesses to the stroke vertices so that the stroke looks
        like made with a calligraphic tool, i.e. the stroke will be the
        thickest in a main direction, and the thinnest in the direction
        perpendicular to this one, and an interpolation in between.

                :param stroke: A Stroke object.
        """

class ColorNoiseShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `ColorNoiseShader`[Color shader]"""

    def __init__(self, amplitude: float, period: float) -> None:
        """Builds a ColorNoiseShader object.

        :param amplitude: The amplitude of the noise signal.
        :param period: The period of the noise signal.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Shader to add noise to the stroke colors.

        :param stroke: A Stroke object.
        """

class ConstantColorShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `ConstantColorShader`[Color shader]"""

    def __init__(
        self, red: float, green: float, blue: float, alpha: float = 1.0
    ) -> None:
        """Builds a ConstantColorShader object.

        :param red: The red component.
        :param green: The green component.
        :param blue: The blue component.
        :param alpha: The alpha value.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Assigns a constant color to every vertex of the Stroke.

        :param stroke: A Stroke object.
        """

class ConstantThicknessShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `ConstantThicknessShader`[Thickness shader]"""

    def __init__(self, thickness: float) -> None:
        """Builds a ConstantThicknessShader object.

        :param thickness: The thickness that must be assigned to the stroke.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Assigns an absolute constant thickness to every vertex of the Stroke.

        :param stroke: A Stroke object.
        """

class ConstrainedIncreasingThicknessShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `ConstrainedIncreasingThicknessShader`[Thickness shader]"""

    def __init__(
        self, thickness_min: float, thickness_max: float, ratio: float
    ) -> None:
        """Builds a ConstrainedIncreasingThicknessShader object.

        :param thickness_min: The minimum thickness.
        :param thickness_max: The maximum thickness.
        :param ratio: The thickness/length ratio that we dont want to exceed.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Same as the `IncreasingThicknessShader`, but here we allow
        the user to control the thickness/length ratio so that we dont get
        fat short lines.

                :param stroke: A Stroke object.
        """

class GuidingLinesShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `GuidingLinesShader`[Geometry shader]"""

    def __init__(self, offset: float) -> None:
        """Builds a GuidingLinesShader object.

                :param offset: The line that replaces the stroke is initially in the
        middle of the initial stroke bounding box. offset is the value
        of the displacement which is applied to this line along its
        normal.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Shader to modify the Stroke geometry so that it corresponds to its
        main direction line. This shader must be used together with the
        splitting operator using the curvature criterion. Indeed, the
        precision of the approximation will depend on the size of the
        strokes pieces. The bigger the pieces are, the rougher the
        approximation is.

                :param stroke: A Stroke object.
        """

class IncreasingColorShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `IncreasingColorShader`[Color shader]"""

    def __init__(
        self,
        red_min: float,
        green_min: float,
        blue_min: float,
        alpha_min: float,
        red_max: float,
        green_max: float,
        blue_max: float,
        alpha_max: float,
    ) -> None:
        """Builds an IncreasingColorShader object.

        :param red_min: The first color red component.
        :param green_min: The first color green component.
        :param blue_min: The first color blue component.
        :param alpha_min: The first color alpha value.
        :param red_max: The second color red component.
        :param green_max: The second color green component.
        :param blue_max: The second color blue component.
        :param alpha_max: The second color alpha value.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Assigns a varying color to the stroke. The user specifies two
        colors A and B. The stroke color will change linearly from A to B
        between the first and the last vertex.

                :param stroke: A Stroke object.
        """

class IncreasingThicknessShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `IncreasingThicknessShader`[Thickness shader]"""

    def __init__(self, thickness_A: float, thickness_B: float) -> None:
        """Builds an IncreasingThicknessShader object.

        :param thickness_A: The first thickness value.
        :param thickness_B: The second thickness value.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Assigns thicknesses values such as the thickness increases from a
        thickness value A to a thickness value B between the first vertex
        to the midpoint vertex and then decreases from B to a A between
        this midpoint vertex and the last vertex. The thickness is
        linearly interpolated from A to B.

                :param stroke: A Stroke object.
        """

class PolygonalizationShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `PolygonalizationShader`[Geometry shader]"""

    def __init__(self, error: float) -> None:
        """Builds a PolygonalizationShader object.

                :param error: The error we want our polygonal approximation to have
        with respect to the original geometry. The smaller, the closer
        the new stroke is to the original one. This error corresponds to
        the maximum distance between the new stroke and the old one.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Modifies the Stroke geometry so that it looks more "polygonal".
        The basic idea is to start from the minimal stroke approximation
        consisting in a line joining the first vertex to the last one and
        to subdivide using the original stroke vertices until a certain
        error is reached.

                :param stroke: A Stroke object.
        """

class RoundCapShader:
    def round_cap_thickness(self, x) -> None:
        """

        :param x:
        """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class SamplingShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `SamplingShader`[Geometry shader]"""

    def __init__(self, sampling: float) -> None:
        """Builds a SamplingShader object.

        :param sampling: The sampling to use for the stroke resampling.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Resamples the stroke.

        :param stroke: A Stroke object.
        """

class SmoothingShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `SmoothingShader`[Geometry shader]"""

    def __init__(
        self,
        num_iterations: int = 100,
        factor_point: float = 0.1,
        factor_curvature: float = 0.0,
        factor_curvature_difference: float = 0.2,
        aniso_point: float = 0.0,
        aniso_normal: float = 0.0,
        aniso_curvature: float = 0.0,
        carricature_factor: float = 1.0,
    ) -> None:
        """Builds a SmoothingShader object.

        :param num_iterations: The number of iterations.
        :param factor_point: 0.1
        :param factor_curvature: 0.0
        :param factor_curvature_difference: 0.2
        :param aniso_point: 0.0
        :param aniso_normal: 0.0
        :param aniso_curvature: 0.0
        :param carricature_factor: 1.0
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Smooths the stroke by moving the vertices to make the stroke
        smoother. Uses curvature flow to converge towards a curve of
        constant curvature. The diffusion method we use is anisotropic to
        prevent the diffusion across corners.

                :param stroke: A Stroke object.
        """

class SpatialNoiseShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `SpatialNoiseShader`[Geometry shader]"""

    def __init__(
        self,
        amount: float,
        scale: float,
        num_octaves: int,
        smooth: bool,
        pure_random: bool,
    ) -> None:
        """Builds a SpatialNoiseShader object.

        :param amount: The amplitude of the noise.
        :param scale: The noise frequency.
        :param num_octaves: The number of octaves
        :param smooth: True if you want the noise to be smooth.
        :param pure_random: True if you dont want any coherence.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Spatial Noise stroke shader. Moves the vertices to make the stroke
        more noisy.

                :param stroke: A Stroke object.
        """

class SquareCapShader:
    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class StrokeTextureStepShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `StrokeTextureStepShader`[Texture shader]"""

    def __init__(self, step: float) -> None:
        """Builds a StrokeTextureStepShader object.

        :param step: The spacing along the stroke.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Assigns a spacing factor to the texture coordinates of the Stroke.

        :param stroke: A Stroke object.
        """

class ThicknessNoiseShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `ThicknessNoiseShader`[Thickness shader]"""

    def __init__(self, amplitude: float, period: float) -> None:
        """Builds a ThicknessNoiseShader object.

        :param amplitude: The amplitude of the noise signal.
        :param period: The period of the noise signal.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Adds some noise to the stroke thickness.

        :param stroke: A Stroke object.
        """

class TipRemoverShader:
    """Class hierarchy: `freestyle.types.StrokeShader` > `TipRemoverShader`[Geometry shader]"""

    def __init__(self, tip_length: float) -> None:
        """Builds a TipRemoverShader object.

                :param tip_length: The length of the piece of stroke we want to remove
        at each extremity.
        """

    def shade(self, stroke: freestyle.types.Stroke) -> None:
        """Removes the strokes extremities.

        :param stroke: A Stroke object.
        """

class py2DCurvatureColorShader:
    """Assigns a color (grayscale) to the stroke based on the curvature.
    A higher curvature will yield a brighter color.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyBackboneStretcherNoCuspShader:
    """Stretches the strokes backbone, excluding cusp vertices (end junctions)."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyBackboneStretcherShader:
    """Stretches the strokes backbone by a given length (in pixels)."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyBluePrintCirclesShader:
    """Draws the silhouette of the object as a circle."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyBluePrintDirectedSquaresShader:
    """Replaces the stroke with a directed square."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyBluePrintEllipsesShader:
    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyBluePrintSquaresShader:
    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyConstantColorShader:
    """Assigns a constant color to the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyConstantThicknessShader:
    """Assigns a constant thickness along the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyConstrainedIncreasingThicknessShader:
    """Increasingly thickens the stroke, constrained by a ratio of the
    strokes length.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyDecreasingThicknessShader:
    """Inverse of pyIncreasingThicknessShader, decreasingly thickens the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyDepthDiscontinuityThicknessShader:
    """Assigns a thickness to the stroke based on the strokes distance
    to the camera (Z-value).
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyDiffusion2Shader:
    """Iteratively adds an offset to the position of each stroke vertex
    in the direction perpendicular to the stroke direction at the
    point. The offset is scaled by the 2D curvature (i.e. how quickly
    the stroke curve is) at the point.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyFXSVaryingThicknessWithDensityShader:
    """Assigns thickness to a stroke based on the density of the diffuse map."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyGuidingLineShader:
    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyHLRShader:
    """Controls visibility based upon the quantitative invisibility (QI)
    based on hidden line removal (HLR).
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyImportance2DThicknessShader:
    """Assigns thickness based on distance to a given point in 2D space.
    the thickness is inverted, so the vertices closest to the
    specified point have the lowest thickness.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyImportance3DThicknessShader:
    """Assigns thickness based on distance to a given point in 3D space."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyIncreasingColorShader:
    """Fades from one color to another along the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyIncreasingThicknessShader:
    """Increasingly thickens the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyInterpolateColorShader:
    """Fades from one color to another and back."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyLengthDependingBackboneStretcherShader:
    """Stretches the strokes backbone proportional to the strokes length
    NOTE: youll probably want an l somewhere between (0.5 - 0). A value that
    is too high may yield unexpected results.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyMaterialColorShader:
    """Assigns the color of the underlying material to the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyModulateAlphaShader:
    """Limits the strokes alpha between a min and max value."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyNonLinearVaryingThicknessShader:
    """Assigns thickness to a stroke based on an exponential function."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyPerlinNoise1DShader:
    """Displaces the stroke using the curvilinear abscissa.  This means
    that lines with the same length and sampling interval will be
    identically distorted.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyPerlinNoise2DShader:
    """Displaces the stroke using the strokes coordinates.  This means
    that in a scene no strokes will be distorted identically.More information on the noise shaders can be found at:
    https://freestyleintegration.wordpress.com/2011/09/25/development-updates-on-september-25/
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyRandomColorShader:
    """Assigns a color to the stroke based on given seed."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pySLERPThicknessShader:
    """Assigns thickness to a stroke based on spherical linear interpolation."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pySamplingShader:
    """Resamples the stroke, which gives the stroke the amount of
    vertices specified.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pySinusDisplacementShader:
    """Displaces the stroke in the shape of a sine wave."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyTVertexRemoverShader:
    """Removes t-vertices from the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyTVertexThickenerShader:
    """Thickens TVertices (visual intersections between two edges)."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyTimeColorShader:
    """Assigns a grayscale value that increases for every vertex.
    The brightness will increase along the stroke.
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

class pyTipRemoverShader:
    """Removes the tips of the stroke."""

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """

    @staticmethod
    def check_vertex(v, length) -> None:
        """

        :param v:
        :param length:
        """

class pyZDependingThicknessShader:
    """Assigns thickness based on an objects local Z depth (point
    closest to camera is 1, point furthest from camera is zero).
    """

    def shade(self, stroke) -> None:
        """

        :param stroke:
        """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def entry_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    list_path: str | None = "",
    active_index_path: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add an entry to the list after the current active item

    :param list_path: list_path, (optional, never None)
    :param active_index_path: active_index_path, (optional, never None)
    :return: Result of the operator call.
    """

def entry_move(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    list_path: str | None = "",
    active_index_path: str | None = "",
    direction: typing.Literal["UP", "DOWN"] | None = "UP",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Move an entry in the list up or down

        :param list_path: list_path, (optional, never None)
        :param active_index_path: active_index_path, (optional, never None)
        :param direction: Direction, (optional)

    UP
    Up -- Move the active entry up.

    DOWN
    Down -- Move the active entry down.
        :return: Result of the operator call.
    """

def entry_remove(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    list_path: str | None = "",
    active_index_path: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove the selected entry from the list

    :param list_path: list_path, (optional, never None)
    :param active_index_path: active_index_path, (optional, never None)
    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def complete(
    line: str, cursor: int, namespace: dict[str, typing.Any]
) -> tuple[str, str, str]:
    """Complete callable with call-tip.

    :param line: incomplete text line
    :param cursor: current character position
    :param namespace: namespace
    :return: (matches, world, scrollback)
    """

def get_argspec(
    func, *, strip_self: bool = True, doc: str | None = None, source: str | None = None
) -> str:
    """Get argument specifications.

    :param strip_self: strip self from argspec
    :param doc: doc string of func (optional)
    :param source: source code of func (optional)
    :return: argument specification
    """

def get_doc(obj) -> str:
    """Get the doc string or comments for an object.

    :return: doc string
    """

def reduce_newlines(text: str) -> str:
    """Reduces multiple newlines to a single newline.

    :param text: text with multiple newlines
    :return: text with single newlines
    """

def reduce_spaces(text: str) -> str:
    """Reduces multiple white-spaces to a single space.

    :param text: text with multiple spaces
    :return: text with single spaces
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def flush_edits(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Flush edit data from active editing modes

    :return: Result of the operator call.
    """

def lib_id_fake_user_toggle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Save this data-block even if it has no users

    :return: Result of the operator call.
    """

def lib_id_generate_preview(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create an automatic preview for the selected data-block

    :return: Result of the operator call.
    """

def lib_id_generate_preview_from_object(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create a preview for this asset by rendering the active object

    :return: Result of the operator call.
    """

def lib_id_load_custom_preview(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
    hide_props_region: bool | None = True,
    check_existing: bool | None = False,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = True,
    filter_movie: bool | None = False,
    filter_python: bool | None = False,
    filter_font: bool | None = False,
    filter_sound: bool | None = False,
    filter_text: bool | None = False,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    show_multiview: bool | None = False,
    use_multiview: bool | None = False,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "DEFAULT",
    sort_method: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Choose an image to help identify the data-block visually

        :param filepath: File Path, Path to file (optional, never None)
        :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings (optional)
        :param check_existing: Check Existing, Check and warn on overwriting existing files (optional)
        :param filter_blender: Filter .blend files, (optional)
        :param filter_backup: Filter backup .blend files, (optional)
        :param filter_image: Filter image files, (optional)
        :param filter_movie: Filter movie files, (optional)
        :param filter_python: Filter Python files, (optional)
        :param filter_font: Filter font files, (optional)
        :param filter_sound: Filter sound files, (optional)
        :param filter_text: Filter text files, (optional)
        :param filter_archive: Filter archive files, (optional)
        :param filter_btx: Filter btx files, (optional)
        :param filter_alembic: Filter Alembic files, (optional)
        :param filter_usd: Filter USD files, (optional)
        :param filter_obj: Filter OBJ files, (optional)
        :param filter_volume: Filter OpenVDB volume files, (optional)
        :param filter_folder: Filter folders, (optional)
        :param filter_blenlib: Filter Blender IDs, (optional)
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file (in [1, 9], optional)
        :param show_multiview: Enable Multi-View, (optional)
        :param use_multiview: Use Multi-View, (optional)
        :param display_type: Display Type, (optional)

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :param sort_method: File sorting mode, (optional)
        :return: Result of the operator call.
    """

def lib_id_override_editable_toggle(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set if this library override data-block can be edited

    :return: Result of the operator call.
    """

def lib_id_remove_preview(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove the preview of this data-block

    :return: Result of the operator call.
    """

def lib_id_unlink(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove a usage of a data-block, clearing the assignment

    :return: Result of the operator call.
    """

def redo(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Redo previous action

    :return: Result of the operator call.
    """

def undo(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Undo previous action

    :return: Result of the operator call.
    """

def undo_history(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    item: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Undo or redo specific action in history

    :param item: Item, (in [0, inf], optional)
    :return: Result of the operator call.
    """

def undo_push(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    message: str | None = "Add an undo step *function may be moved*",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add an undo state (internal use only)

    :param message: Undo Message, (optional, never None)
    :return: Result of the operator call.
    """

def undo_redo(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Undo and redo previous action

    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def mutex_lock(local_library_path) -> None:
    """Lock the library for syncing.Create a file on disk that signals to other Blender instances that this
    remote asset library is being synced by this Blender.

        :return: true if the lock was created successfully, false if some other
    Blender already locked this library.
    """

def mutex_unlock(local_library_path) -> None:
    """Remove the lock created by mutex_lock(local_library_path)."""



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def add_game_prop(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Adds a property available to the UPBGE

    :return: Result of the operator call.
    """

def move_game_prop(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    index: int | None = 0,
    direction: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Move Game Property

    :param index: index, (in [-inf, inf], optional)
    :param direction: direction, (optional, never None)
    :return: Result of the operator call.
    """

def remove_game_prop(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    index: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove this property

    :param index: index, (in [-inf, inf], optional)
    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums
import mathutils

def add_render_slot(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add a new render slot

    :return: Result of the operator call.
    """

def change_frame(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    frame: int | None = 0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Interactively change the current frame number

    :param frame: Frame, (in [-1048574, 1048574], optional)
    :return: Result of the operator call.
    """

def clear_render_border(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Clear the boundaries of the render region and disable render region

    :return: Result of the operator call.
    """

def clear_render_slot(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Clear the currently selected render slot

    :return: Result of the operator call.
    """

def clipboard_copy(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy the image to the clipboard

    :return: Result of the operator call.
    """

def clipboard_paste(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Paste new image from the clipboard

    :return: Result of the operator call.
    """

def convert_to_mesh_plane(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    interpolation: typing.Literal["Linear", "Closest", "Cubic", "Smart"]
    | None = "Linear",
    extension: typing.Literal["CLIP", "EXTEND", "REPEAT"] | None = "CLIP",
    use_auto_refresh: bool | None = True,
    relative: bool | None = True,
    shader: typing.Literal["PRINCIPLED", "SHADELESS", "EMISSION"] | None = "PRINCIPLED",
    emit_strength: float | None = 1.0,
    use_transparency: bool | None = True,
    render_method: typing.Literal["DITHERED", "BLENDED"] | None = "DITHERED",
    use_backface_culling: bool | None = False,
    show_transparent_back: bool | None = True,
    overwrite_material: bool | None = True,
    name_from: typing.Literal["OBJECT", "IMAGE"] | None = "OBJECT",
    delete_ref: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Convert selected reference images to textured mesh plane

        :param interpolation: Interpolation, Texture interpolation (optional)

    Linear
    Linear -- Linear interpolation.

    Closest
    Closest -- No interpolation (sample closest texel).

    Cubic
    Cubic -- Cubic interpolation.

    Smart
    Smart -- Bicubic when magnifying, else bilinear (OSL only).
        :param extension: Extension, How the image is extrapolated past its original bounds (optional)

    CLIP
    Clip -- Clip to image size and set exterior pixels as transparent.

    EXTEND
    Extend -- Extend by repeating edge pixels of the image.

    REPEAT
    Repeat -- Cause the image to repeat horizontally and vertically.
        :param use_auto_refresh: Auto Refresh, Always refresh image on frame changes (optional)
        :param relative: Relative Paths, Use relative file paths (optional)
        :param shader: Shader, Node shader to use (optional)

    PRINCIPLED
    Principled -- Principled shader.

    SHADELESS
    Shadeless -- Only visible to camera and reflections.

    EMISSION
    Emission -- Emission shader.
        :param emit_strength: Emission Strength, Strength of emission (in [0, inf], optional)
        :param use_transparency: Use Alpha, Use alpha channel for transparency (optional)
        :param render_method: Render Method, (optional)

    DITHERED
    Dithered -- Allows for grayscale hashed transparency, and compatible with render passes and ray-tracing. Also known as deferred rendering..

    BLENDED
    Blended -- Allows for colored transparency, but incompatible with render passes and ray-tracing. Also known as forward rendering..
        :param use_backface_culling: Backface Culling, Use backface culling to hide the back side of faces (optional)
        :param show_transparent_back: Show Backface, Render multiple transparent layers (may introduce transparency sorting problems) (optional)
        :param overwrite_material: Overwrite Material, Overwrite existing material with the same name (optional)
        :param name_from: Name After, Name for new mesh object and material (optional)

    OBJECT
    Source Object -- Name after object source with a suffix.

    IMAGE
    Source Image -- Name from loaded image.
        :param delete_ref: Delete Reference Object, Delete empty image object once mesh plane is created (optional)
        :return: Result of the operator call.
    """

def curves_point_set(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    point: typing.Literal["BLACK_POINT", "WHITE_POINT"] | None = "BLACK_POINT",
    size: int | None = 1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set black point or white point for curves

    :param point: Point, Set black point or white point for curves (optional)
    :param size: Sample Size, (in [1, 128], optional)
    :return: Result of the operator call.
    """

def cycle_render_slot(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    reverse: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Cycle through all non-void render slots

    :param reverse: Cycle in Reverse, (optional)
    :return: Result of the operator call.
    """

def external_edit(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Edit image in an external application

    :param filepath: filepath, (optional, never None)
    :return: Result of the operator call.
    """

def file_browse(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
    hide_props_region: bool | None = True,
    check_existing: bool | None = False,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = True,
    filter_movie: bool | None = True,
    filter_python: bool | None = False,
    filter_font: bool | None = False,
    filter_sound: bool | None = False,
    filter_text: bool | None = False,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    relative_path: bool | None = True,
    show_multiview: bool | None = False,
    use_multiview: bool | None = False,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "DEFAULT",
    sort_method: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Open an image file browser, hold Shift to open the file, Alt to browse containing directory

        :param filepath: File Path, Path to file (optional, never None)
        :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings (optional)
        :param check_existing: Check Existing, Check and warn on overwriting existing files (optional)
        :param filter_blender: Filter .blend files, (optional)
        :param filter_backup: Filter backup .blend files, (optional)
        :param filter_image: Filter image files, (optional)
        :param filter_movie: Filter movie files, (optional)
        :param filter_python: Filter Python files, (optional)
        :param filter_font: Filter font files, (optional)
        :param filter_sound: Filter sound files, (optional)
        :param filter_text: Filter text files, (optional)
        :param filter_archive: Filter archive files, (optional)
        :param filter_btx: Filter btx files, (optional)
        :param filter_alembic: Filter Alembic files, (optional)
        :param filter_usd: Filter USD files, (optional)
        :param filter_obj: Filter OBJ files, (optional)
        :param filter_volume: Filter OpenVDB volume files, (optional)
        :param filter_folder: Filter folders, (optional)
        :param filter_blenlib: Filter Blender IDs, (optional)
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file (in [1, 9], optional)
        :param relative_path: Relative Path, Select the file relative to the blend file (optional)
        :param show_multiview: Enable Multi-View, (optional)
        :param use_multiview: Use Multi-View, (optional)
        :param display_type: Display Type, (optional)

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :param sort_method: File sorting mode, (optional)
        :return: Result of the operator call.
    """

def flip(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    use_flip_x: bool | None = False,
    use_flip_y: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Flip the image

    :param use_flip_x: Horizontal, Flip the image horizontally (optional)
    :param use_flip_y: Vertical, Flip the image vertically (optional)
    :return: Result of the operator call.
    """

def import_as_mesh_planes(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    interpolation: typing.Literal["Linear", "Closest", "Cubic", "Smart"]
    | None = "Linear",
    extension: typing.Literal["CLIP", "EXTEND", "REPEAT"] | None = "CLIP",
    use_auto_refresh: bool | None = True,
    relative: bool | None = True,
    shader: typing.Literal["PRINCIPLED", "SHADELESS", "EMISSION"] | None = "PRINCIPLED",
    emit_strength: float | None = 1.0,
    use_transparency: bool | None = True,
    render_method: typing.Literal["DITHERED", "BLENDED"] | None = "DITHERED",
    use_backface_culling: bool | None = False,
    show_transparent_back: bool | None = True,
    overwrite_material: bool | None = True,
    filepath: str | None = "",
    align: typing.Literal["WORLD", "VIEW", "CURSOR"] | None = "WORLD",
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (
        0.0,
        0.0,
        0.0,
    ),
    rotation: collections.abc.Sequence[float] | mathutils.Euler | None = (
        0.0,
        0.0,
        0.0,
    ),
    files=None,
    directory: str | None = "",
    filter_image: bool | None = True,
    filter_movie: bool | None = True,
    filter_folder: bool | None = True,
    force_reload: bool | None = False,
    image_sequence: bool | None = False,
    offset: bool | None = True,
    offset_axis: typing.Literal["+X", "+Y", "+Z", "-X", "-Y", "-Z"] | None = "+X",
    offset_amount: float | None = 0.1,
    align_axis: typing.Literal["+X", "+Y", "+Z", "-X", "-Y", "-Z", "CAM", "CAM_AX"]
    | None = "CAM_AX",
    prev_align_axis: typing.Literal[
        "+X", "+Y", "+Z", "-X", "-Y", "-Z", "CAM", "CAM_AX", "NONE"
    ]
    | None = "NONE",
    align_track: bool | None = False,
    size_mode: typing.Literal["ABSOLUTE", "CAMERA", "DPI", "DPBU"] | None = "ABSOLUTE",
    fill_mode: typing.Literal["FILL", "FIT"] | None = "FILL",
    height: float | None = 1.0,
    factor: float | None = 600.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create mesh plane(s) from image files with the appropriate aspect ratio

        :param interpolation: Interpolation, Texture interpolation (optional)

    Linear
    Linear -- Linear interpolation.

    Closest
    Closest -- No interpolation (sample closest texel).

    Cubic
    Cubic -- Cubic interpolation.

    Smart
    Smart -- Bicubic when magnifying, else bilinear (OSL only).
        :param extension: Extension, How the image is extrapolated past its original bounds (optional)

    CLIP
    Clip -- Clip to image size and set exterior pixels as transparent.

    EXTEND
    Extend -- Extend by repeating edge pixels of the image.

    REPEAT
    Repeat -- Cause the image to repeat horizontally and vertically.
        :param use_auto_refresh: Auto Refresh, Always refresh image on frame changes (optional)
        :param relative: Relative Paths, Use relative file paths (optional)
        :param shader: Shader, Node shader to use (optional)

    PRINCIPLED
    Principled -- Principled shader.

    SHADELESS
    Shadeless -- Only visible to camera and reflections.

    EMISSION
    Emission -- Emission shader.
        :param emit_strength: Emission Strength, Strength of emission (in [0, inf], optional)
        :param use_transparency: Use Alpha, Use alpha channel for transparency (optional)
        :param render_method: Render Method, (optional)

    DITHERED
    Dithered -- Allows for grayscale hashed transparency, and compatible with render passes and ray-tracing. Also known as deferred rendering..

    BLENDED
    Blended -- Allows for colored transparency, but incompatible with render passes and ray-tracing. Also known as forward rendering..
        :param use_backface_culling: Backface Culling, Use backface culling to hide the back side of faces (optional)
        :param show_transparent_back: Show Backface, Render multiple transparent layers (may introduce transparency sorting problems) (optional)
        :param overwrite_material: Overwrite Material, Overwrite existing material with the same name (optional)
        :param filepath: File Path, Filepath used for importing the file (optional, never None)
        :param align: Align, (optional)

    WORLD
    World -- Align the new object to the world.

    VIEW
    View -- Align the new object to the view.

    CURSOR
    3D Cursor -- Use the 3D cursor orientation for the new object.
        :param location: Location, (array of 3 items, in [-inf, inf], optional)
        :param rotation: Rotation, (array of 3 items, in [-inf, inf], optional)
        :param files: files, (optional)
        :param directory: directory, (optional, never None)
        :param filter_image: filter_image, (optional)
        :param filter_movie: filter_movie, (optional)
        :param filter_folder: filter_folder, (optional)
        :param force_reload: Force Reload, Force reload the image if it is already opened elsewhere in Blender (optional)
        :param image_sequence: Detect Image Sequences, Import sequentially numbered images as an animated image sequence instead of separate planes (optional)
        :param offset: Offset Planes, Offset planes from each other. If disabled, multiple planes will be created at the same location (optional)
        :param offset_axis: Offset Direction, How planes are oriented relative to each others local axis (optional)

    +X
    +X -- Side by Side to the Left.

    +Y
    +Y -- Side by Side, Downward.

    +Z
    +Z -- Stacked Above.

    -X
    -X -- Side by Side to the Right.

    -Y
    -Y -- Side by Side, Upward.

    -Z
    -Z -- Stacked Below.
        :param offset_amount: Offset Distance, Set distance between each plane (in [-inf, inf], optional)
        :param align_axis: Align, How to align the planes (optional)

    +X
    +X -- Facing positive X.

    +Y
    +Y -- Facing positive Y.

    +Z
    +Z -- Facing positive Z.

    -X
    -X -- Facing negative X.

    -Y
    -Y -- Facing negative Y.

    -Z
    -Z -- Facing negative Z.

    CAM
    Face Camera -- Facing camera.

    CAM_AX
    Cameras Main Axis -- Facing the cameras dominant axis.
        :param prev_align_axis: prev_align_axis, (optional)

    +X
    +X -- Facing positive X.

    +Y
    +Y -- Facing positive Y.

    +Z
    +Z -- Facing positive Z.

    -X
    -X -- Facing negative X.

    -Y
    -Y -- Facing negative Y.

    -Z
    -Z -- Facing negative Z.

    CAM
    Face Camera -- Facing camera.

    CAM_AX
    Cameras Main Axis -- Facing the cameras dominant axis.

    NONE
    Undocumented.
        :param align_track: Track Camera, Add a constraint to make the planes track the camera (optional)
        :param size_mode: Size Mode, Method for computing the plane size (optional)

    ABSOLUTE
    Absolute -- Use absolute size.

    CAMERA
    Scale to Camera Frame -- Scale to fit or fill the camera frame.

    DPI
    Pixels per Inch -- Scale based on pixels per inch.

    DPBU
    Pixels per Blender Unit -- Scale based on pixels per Blender Unit.
        :param fill_mode: Scale, Method to scale the plane with the camera frame (optional)

    FILL
    Fill -- Fill camera frame, spilling outside the frame.

    FIT
    Fit -- Fit entire image within the camera frame.
        :param height: Height, Height of the created plane (in [0.001, inf], optional)
        :param factor: Definition, Number of pixels per inch or Blender Unit (in [1, inf], optional)
        :return: Result of the operator call.
    """

def invert(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    invert_r: bool | None = False,
    invert_g: bool | None = False,
    invert_b: bool | None = False,
    invert_a: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Invert images channels

    :param invert_r: Red, Invert red channel (optional)
    :param invert_g: Green, Invert green channel (optional)
    :param invert_b: Blue, Invert blue channel (optional)
    :param invert_a: Alpha, Invert alpha channel (optional)
    :return: Result of the operator call.
    """

def match_movie_length(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set the images frame range to match the videos duration

    :return: Result of the operator call.
    """

def new(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    name: str | None = "Untitled",
    width: int | None = 1024,
    height: int | None = 1024,
    color: collections.abc.Sequence[float] | None = (0.0, 0.0, 0.0, 1.0),
    alpha: bool | None = True,
    generated_type: Literal[bpy.stub_internal.rna_enums.ImageGeneratedTypeItems]
    | None = "BLANK",
    float: bool | None = False,
    use_stereo_3d: bool | None = False,
    tiled: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Create a new image

    :param name: Name, Image data-block name (optional, never None)
    :param width: Width, Image width (in [1, inf], optional)
    :param height: Height, Image height (in [1, inf], optional)
    :param color: Color, Default fill color (array of 4 items, in [0, inf], optional)
    :param alpha: Alpha, Create an image with an alpha channel (optional)
    :param generated_type: Generated Type, Fill the image with a grid for UV map testing (optional)
    :param float: 32-bit Float, Create image with 32-bit floating-point bit depth (optional)
    :param use_stereo_3d: Stereo 3D, Create an image with left and right views (optional)
    :param tiled: Tiled, Create a tiled image (optional)
    :return: Result of the operator call.
    """

def open(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    allow_path_tokens: bool | None = True,
    filepath: str | None = "",
    directory: str | None = "",
    files=None,
    hide_props_region: bool | None = True,
    check_existing: bool | None = False,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = True,
    filter_movie: bool | None = True,
    filter_python: bool | None = False,
    filter_font: bool | None = False,
    filter_sound: bool | None = False,
    filter_text: bool | None = False,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    relative_path: bool | None = True,
    show_multiview: bool | None = False,
    use_multiview: bool | None = False,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "DEFAULT",
    sort_method: str | None = "",
    use_sequence_detection: bool | None = True,
    use_udim_detecting: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Open image

        :param allow_path_tokens: Allow the path to contain substitution tokens (optional)
        :param filepath: File Path, Path to file (optional, never None)
        :param directory: Directory, Directory of the file (optional, never None)
        :param files: Files, (optional)
        :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings (optional)
        :param check_existing: Check Existing, Check and warn on overwriting existing files (optional)
        :param filter_blender: Filter .blend files, (optional)
        :param filter_backup: Filter backup .blend files, (optional)
        :param filter_image: Filter image files, (optional)
        :param filter_movie: Filter movie files, (optional)
        :param filter_python: Filter Python files, (optional)
        :param filter_font: Filter font files, (optional)
        :param filter_sound: Filter sound files, (optional)
        :param filter_text: Filter text files, (optional)
        :param filter_archive: Filter archive files, (optional)
        :param filter_btx: Filter btx files, (optional)
        :param filter_alembic: Filter Alembic files, (optional)
        :param filter_usd: Filter USD files, (optional)
        :param filter_obj: Filter OBJ files, (optional)
        :param filter_volume: Filter OpenVDB volume files, (optional)
        :param filter_folder: Filter folders, (optional)
        :param filter_blenlib: Filter Blender IDs, (optional)
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file (in [1, 9], optional)
        :param relative_path: Relative Path, Select the file relative to the blend file (optional)
        :param show_multiview: Enable Multi-View, (optional)
        :param use_multiview: Use Multi-View, (optional)
        :param display_type: Display Type, (optional)

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :param sort_method: File sorting mode, (optional)
        :param use_sequence_detection: Detect Sequences, Automatically detect animated sequences in selected images (based on file names) (optional)
        :param use_udim_detecting: Detect UDIMs, Detect selected UDIM files and load all matching tiles (optional)
        :return: Result of the operator call.
    """

def open_images(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    directory: str | None = "",
    files=None,
    relative_path: bool | None = True,
    use_sequence_detection: bool | None = True,
    use_udim_detection: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Undocumented, consider contributing.

    :param directory: directory, (optional, never None)
    :param files: files, (optional)
    :param relative_path: Use relative path, (optional)
    :param use_sequence_detection: Use sequence detection, (optional)
    :param use_udim_detection: Use UDIM detection, (optional)
    :return: Result of the operator call.
    """

def pack(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Pack an image as embedded data into the .blend file

    :return: Result of the operator call.
    """

def project_apply(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Project edited image back onto the object

    :return: Result of the operator call.
    """

def project_edit(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Edit a snapshot of the 3D Viewport in an external image editor

    :return: Result of the operator call.
    """

def read_viewlayers(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Read all the current scenes view layers from cache, as needed

    :return: Result of the operator call.
    """

def reload(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Reload current image from disk

    :return: Result of the operator call.
    """

def remove_render_slot(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove the current render slot

    :return: Result of the operator call.
    """

def render_border(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    xmin: int | None = 0,
    xmax: int | None = 0,
    ymin: int | None = 0,
    ymax: int | None = 0,
    wait_for_input: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set the boundaries of the render region and enable render region

    :param xmin: X Min, (in [-inf, inf], optional)
    :param xmax: X Max, (in [-inf, inf], optional)
    :param ymin: Y Min, (in [-inf, inf], optional)
    :param ymax: Y Max, (in [-inf, inf], optional)
    :param wait_for_input: Wait for Input, (optional)
    :return: Result of the operator call.
    """

def replace(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    filepath: str | None = "",
    hide_props_region: bool | None = True,
    check_existing: bool | None = False,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = True,
    filter_movie: bool | None = True,
    filter_python: bool | None = False,
    filter_font: bool | None = False,
    filter_sound: bool | None = False,
    filter_text: bool | None = False,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    relative_path: bool | None = True,
    show_multiview: bool | None = False,
    use_multiview: bool | None = False,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "DEFAULT",
    sort_method: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Replace current image by another one from disk

        :param filepath: File Path, Path to file (optional, never None)
        :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings (optional)
        :param check_existing: Check Existing, Check and warn on overwriting existing files (optional)
        :param filter_blender: Filter .blend files, (optional)
        :param filter_backup: Filter backup .blend files, (optional)
        :param filter_image: Filter image files, (optional)
        :param filter_movie: Filter movie files, (optional)
        :param filter_python: Filter Python files, (optional)
        :param filter_font: Filter font files, (optional)
        :param filter_sound: Filter sound files, (optional)
        :param filter_text: Filter text files, (optional)
        :param filter_archive: Filter archive files, (optional)
        :param filter_btx: Filter btx files, (optional)
        :param filter_alembic: Filter Alembic files, (optional)
        :param filter_usd: Filter USD files, (optional)
        :param filter_obj: Filter OBJ files, (optional)
        :param filter_volume: Filter OpenVDB volume files, (optional)
        :param filter_folder: Filter folders, (optional)
        :param filter_blenlib: Filter Blender IDs, (optional)
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file (in [1, 9], optional)
        :param relative_path: Relative Path, Select the file relative to the blend file (optional)
        :param show_multiview: Enable Multi-View, (optional)
        :param use_multiview: Use Multi-View, (optional)
        :param display_type: Display Type, (optional)

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :param sort_method: File sorting mode, (optional)
        :return: Result of the operator call.
    """

def resize(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    size: collections.abc.Sequence[int] | None = (0, 0),
    all_udims: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Resize the image

    :param size: Size, (array of 2 items, in [1, inf], optional)
    :param all_udims: All UDIM Tiles, Scale all the images UDIM tiles (optional)
    :return: Result of the operator call.
    """

def rotate_orthogonal(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    degrees: typing.Literal["90", "180", "270"] | None = "90",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Rotate the image

        :param degrees: Degrees, Amount of rotation in degrees (90, 180, 270) (optional)

    90
    90 Degrees -- Rotate 90 degrees clockwise.

    180
    180 Degrees -- Rotate 180 degrees clockwise.

    270
    270 Degrees -- Rotate 270 degrees clockwise.
        :return: Result of the operator call.
    """

def sample(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    size: int | None = 1,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Use mouse to sample a color in current image

    :param size: Sample Size, (in [1, 128], optional)
    :return: Result of the operator call.
    """

def sample_line(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    xstart: int | None = 0,
    xend: int | None = 0,
    ystart: int | None = 0,
    yend: int | None = 0,
    flip: bool | None = False,
    cursor: int | None = 5,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Sample a line and show it in Scope panels

    :param xstart: X Start, (in [-inf, inf], optional)
    :param xend: X End, (in [-inf, inf], optional)
    :param ystart: Y Start, (in [-inf, inf], optional)
    :param yend: Y End, (in [-inf, inf], optional)
    :param flip: Flip, (optional)
    :param cursor: Cursor, Mouse cursor style to use during the modal operator (in [0, inf], optional)
    :return: Result of the operator call.
    """

def save(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Save the image with current name and settings

    :return: Result of the operator call.
    """

def save_all_modified(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Save all modified images

    :return: Result of the operator call.
    """

def save_as(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    save_as_render: bool | None = False,
    copy: bool | None = False,
    allow_path_tokens: bool | None = True,
    filepath: str | None = "",
    check_existing: bool | None = True,
    filter_blender: bool | None = False,
    filter_backup: bool | None = False,
    filter_image: bool | None = True,
    filter_movie: bool | None = True,
    filter_python: bool | None = False,
    filter_font: bool | None = False,
    filter_sound: bool | None = False,
    filter_text: bool | None = False,
    filter_archive: bool | None = False,
    filter_btx: bool | None = False,
    filter_alembic: bool | None = False,
    filter_usd: bool | None = False,
    filter_obj: bool | None = False,
    filter_volume: bool | None = False,
    filter_folder: bool | None = True,
    filter_blenlib: bool | None = False,
    filemode: int | None = 9,
    relative_path: bool | None = True,
    show_multiview: bool | None = False,
    use_multiview: bool | None = False,
    display_type: typing.Literal[
        "DEFAULT", "LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"
    ]
    | None = "DEFAULT",
    sort_method: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Save the image with another name and/or settings

        :param save_as_render: Save As Render, Save image with render color management.For display image formats like PNG, apply view and display transform.For intermediate image formats like OpenEXR, use the default render output color space(optional)
        :param copy: Copy, Create a new image file without modifying the current image in Blender (optional)
        :param allow_path_tokens: Allow the path to contain substitution tokens (optional)
        :param filepath: File Path, Path to file (optional, never None)
        :param check_existing: Check Existing, Check and warn on overwriting existing files (optional)
        :param filter_blender: Filter .blend files, (optional)
        :param filter_backup: Filter backup .blend files, (optional)
        :param filter_image: Filter image files, (optional)
        :param filter_movie: Filter movie files, (optional)
        :param filter_python: Filter Python files, (optional)
        :param filter_font: Filter font files, (optional)
        :param filter_sound: Filter sound files, (optional)
        :param filter_text: Filter text files, (optional)
        :param filter_archive: Filter archive files, (optional)
        :param filter_btx: Filter btx files, (optional)
        :param filter_alembic: Filter Alembic files, (optional)
        :param filter_usd: Filter USD files, (optional)
        :param filter_obj: Filter OBJ files, (optional)
        :param filter_volume: Filter OpenVDB volume files, (optional)
        :param filter_folder: Filter folders, (optional)
        :param filter_blenlib: Filter Blender IDs, (optional)
        :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file (in [1, 9], optional)
        :param relative_path: Relative Path, Select the file relative to the blend file (optional)
        :param show_multiview: Enable Multi-View, (optional)
        :param use_multiview: Use Multi-View, (optional)
        :param display_type: Display Type, (optional)

    DEFAULT
    Default -- Automatically determine display type for files.

    LIST_VERTICAL
    Short List -- Display files as short list.

    LIST_HORIZONTAL
    Long List -- Display files as a detailed list.

    THUMBNAIL
    Thumbnails -- Display files as thumbnails.
        :param sort_method: File sorting mode, (optional)
        :return: Result of the operator call.
    """

def save_sequence(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Save a sequence of images

    :return: Result of the operator call.
    """

def tile_add(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    number: int | None = 1002,
    count: int | None = 1,
    label: str | None = "",
    fill: bool | None = True,
    color: collections.abc.Sequence[float] | None = (0.0, 0.0, 0.0, 1.0),
    generated_type: Literal[bpy.stub_internal.rna_enums.ImageGeneratedTypeItems]
    | None = "BLANK",
    width: int | None = 1024,
    height: int | None = 1024,
    float: bool | None = False,
    alpha: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Adds a tile to the image

    :param number: Number, UDIM number of the tile (in [1001, 2000], optional)
    :param count: Count, How many tiles to add (in [1, inf], optional)
    :param label: Label, Optional tile label (optional, never None)
    :param fill: Fill, Fill new tile with a generated image (optional)
    :param color: Color, Default fill color (array of 4 items, in [0, inf], optional)
    :param generated_type: Generated Type, Fill the image with a grid for UV map testing (optional)
    :param width: Width, Image width (in [1, inf], optional)
    :param height: Height, Image height (in [1, inf], optional)
    :param float: 32-bit Float, Create image with 32-bit floating-point bit depth (optional)
    :param alpha: Alpha, Create an image with an alpha channel (optional)
    :return: Result of the operator call.
    """

def tile_fill(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    color: collections.abc.Sequence[float] | None = (0.0, 0.0, 0.0, 1.0),
    generated_type: Literal[bpy.stub_internal.rna_enums.ImageGeneratedTypeItems]
    | None = "BLANK",
    width: int | None = 1024,
    height: int | None = 1024,
    float: bool | None = False,
    alpha: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Fill the current tile with a generated image

    :param color: Color, Default fill color (array of 4 items, in [0, inf], optional)
    :param generated_type: Generated Type, Fill the image with a grid for UV map testing (optional)
    :param width: Width, Image width (in [1, inf], optional)
    :param height: Height, Image height (in [1, inf], optional)
    :param float: 32-bit Float, Create image with 32-bit floating-point bit depth (optional)
    :param alpha: Alpha, Create an image with an alpha channel (optional)
    :return: Result of the operator call.
    """

def tile_remove(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Removes a tile from the image

    :return: Result of the operator call.
    """

def unpack(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    method: Literal[bpy.stub_internal.rna_enums.UnpackMethodItems] | None = "USE_LOCAL",
    id: str | None = "",
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Save an image packed in the .blend file to disk

    :param method: Method, How to unpack (optional)
    :param id: Image Name, Image data-block name to unpack (optional, never None)
    :return: Result of the operator call.
    """

def view_all(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    fit_view: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """View the entire image

    :param fit_view: Fit View, Fit frame to the viewport (optional)
    :return: Result of the operator call.
    """

def view_center_cursor(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Center the view so that the cursor is in the middle of the view

    :return: Result of the operator call.
    """

def view_cursor_center(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    fit_view: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set 2D cursor to center view location

    :param fit_view: Fit View, Fit frame to the viewport (optional)
    :return: Result of the operator call.
    """

def view_ndof(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Use a 3D mouse device to pan/zoom the view

    :return: Result of the operator call.
    """

def view_pan(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    offset: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Pan the view

    :param offset: Offset, Offset in floating-point units, 1.0 is the width and height of the image (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def view_selected(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """View all selected UVs

    :return: Result of the operator call.
    """

def view_zoom(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    factor: float | None = 0.0,
    use_cursor_init: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Zoom in/out the image

    :param factor: Factor, Zoom factor, values higher than 1.0 zoom in, lower values zoom out (in [-inf, inf], optional)
    :param use_cursor_init: Use Mouse Position, Allow the initial mouse position to be used (optional)
    :return: Result of the operator call.
    """

def view_zoom_border(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    xmin: int | None = 0,
    xmax: int | None = 0,
    ymin: int | None = 0,
    ymax: int | None = 0,
    wait_for_input: bool | None = True,
    zoom_out: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Zoom in the view to the nearest item contained in the border

    :param xmin: X Min, (in [-inf, inf], optional)
    :param xmax: X Max, (in [-inf, inf], optional)
    :param ymin: Y Min, (in [-inf, inf], optional)
    :param ymax: Y Max, (in [-inf, inf], optional)
    :param wait_for_input: Wait for Input, (optional)
    :param zoom_out: Zoom Out, (optional)
    :return: Result of the operator call.
    """

def view_zoom_in(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Zoom in the image (centered around 2D cursor)

    :param location: Location, Cursor location in screen coordinates (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def view_zoom_out(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    location: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Zoom out the image (centered around 2D cursor)

    :param location: Location, Cursor location in screen coordinates (array of 2 items, in [-inf, inf], optional)
    :return: Result of the operator call.
    """

def view_zoom_ratio(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    ratio: float | None = 0.0,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Set zoom ratio of the view

    :param ratio: Ratio, Zoom ratio, 1.0 is 1:1, higher is zoomed in, lower is zoomed out (in [-inf, inf], optional)
    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def copy(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Copy the material settings and nodes

    :return: Result of the operator call.
    """

def new(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add a new material

    :return: Result of the operator call.
    """

def paste(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Paste the material settings and nodes

    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.stub_internal.rna_enums

def add_point(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    location: collections.abc.Sequence[int] | None = (0, 0),
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add New Paint Curve Point

    :param location: Location, Location of vertex in area space (array of 2 items, in [0, 32767], optional)
    :return: Result of the operator call.
    """

def add_point_slide(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    PAINTCURVE_OT_add_point: dict[str, typing.Any] | None = {},
    PAINTCURVE_OT_slide: dict[str, typing.Any] | None = {},
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add new curve point and slide it

    :param PAINTCURVE_OT_add_point: Add New Paint Curve Point, Add New Paint Curve Point (optional, `bpy.ops.paintcurve.add_point` keyword arguments)
    :param PAINTCURVE_OT_slide: Slide Paint Curve Point, Select and slide paint curve point (optional, `bpy.ops.paintcurve.slide` keyword arguments)
    :return: Result of the operator call.
    """

def cursor(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Place cursor

    :return: Result of the operator call.
    """

def delete_point(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Remove Paint Curve Point

    :return: Result of the operator call.
    """

def draw(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Draw curve

    :return: Result of the operator call.
    """

def new(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Add new paint curve

    :return: Result of the operator call.
    """

def select(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    location: collections.abc.Sequence[int] | None = (0, 0),
    toggle: bool | None = False,
    extend: bool | None = False,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select a paint curve point

    :param location: Location, Location of vertex in area space (array of 2 items, in [0, 32767], optional)
    :param toggle: Toggle, (De)select all (optional)
    :param extend: Extend, Extend selection (optional)
    :return: Result of the operator call.
    """

def slide(
    execution_context: int | str | None = None,
    undo: bool | None = None,
    /,
    *,
    align: bool | None = False,
    select: bool | None = True,
) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
    """Select and slide paint curve point

    :param align: Align Handles, Aligns opposite point handle during transform (optional)
    :param select: Select, Attempt to select a point handle before transform (optional)
    :return: Result of the operator call.
    """



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

class InfoFunctionRNA:
    args: typing.Any
    bl_func: typing.Any
    description: typing.Any
    global_lookup: typing.Any
    identifier: typing.Any
    is_classmethod: typing.Any
    return_values: typing.Any

    def build(self) -> None: ...

class InfoOperatorRNA:
    args: typing.Any
    bl_op: typing.Any
    description: typing.Any
    func_name: typing.Any
    global_lookup: typing.Any
    identifier: typing.Any
    module_name: typing.Any
    name: typing.Any

    def build(self) -> None: ...
    def get_location(self) -> None: ...

class InfoPropertyRNA:
    array_dimensions: typing.Any
    array_length: typing.Any
    bl_prop: typing.Any
    collection_type: typing.Any
    default: typing.Any
    default_str: typing.Any
    deprecated: typing.Any
    description: typing.Any
    enum_items: typing.Any
    enum_pointer: typing.Any
    fixed_type: typing.Any
    global_lookup: typing.Any
    identifier: typing.Any
    is_argument_optional: typing.Any
    is_enum_flag: typing.Any
    is_never_none: typing.Any
    is_path_supports_blend_relative: typing.Any
    is_path_supports_templates: typing.Any
    is_readonly: typing.Any
    is_required: typing.Any
    max: typing.Any
    min: typing.Any
    name: typing.Any
    srna: typing.Any
    subtype: typing.Any
    type: typing.Any

    def build(self) -> None: ...
    def get_arg_default(self, force=True) -> None:
        """

        :param force:
        """

    def get_type_description(
        self,
        *,
        as_ret=False,
        as_arg=False,
        class_fmt="{:s}",
        mathutils_fmt="{:s}",
        literal_fmt="'{:s}'",
        collection_id="Collection",
        enum_descr_override: None | str | None = None,
    ) -> None:
        """Return a (type_hint, type_info) pair.type_hint follows Python type-hint conventions as closely as possible
        (e.g. bool, Literal[A, B], Matrix).type_info is a list of human-readable strings that describe array
        dimensions, numeric range, default value, and qualifiers such as
        (readonly) or (never None).

                :param as_ret:
                :param as_arg:
                :param class_fmt:
                :param mathutils_fmt:
                :param literal_fmt:
                :param collection_id:
                :param enum_descr_override: Optionally override items for enum.
        Otherwise expand the literal items.
        """

class InfoStructRNA:
    base: typing.Any
    bl_rna: typing.Any
    children: typing.Any
    description: typing.Any
    full_path: typing.Any
    functions: typing.Any
    global_lookup: typing.Any
    identifier: typing.Any
    module_name: typing.Any
    name: typing.Any
    nested: typing.Any
    properties: typing.Any
    py_class: typing.Any
    references: typing.Any

    def build(self) -> None: ...
    def get_bases(self) -> None: ...
    def get_nested_properties(self, ls=None) -> None:
        """

        :param ls:
        """

    def get_py_c_functions(self) -> None: ...
    def get_py_c_properties_getset(self) -> None: ...
    def get_py_functions(self) -> None: ...
    def get_py_properties(self) -> None: ...
    def is_operator_properties(self) -> None: ...

def BuildRNAInfo() -> None: ...
def GetInfoFunctionRNA(bl_rna, parent_id) -> None: ...
def GetInfoOperatorRNA(bl_rna) -> None: ...
def GetInfoPropertyRNA(bl_rna, parent_id) -> None: ...
def GetInfoStructRNA(bl_rna) -> None: ...
def float_as_string(f) -> None: ...
def get_direct_functions(rna_type) -> None: ...
def get_direct_properties(rna_type) -> None: ...
def get_py_class_from_rna(rna_type) -> None:
    """Gets the Python type for a class which isnt necessarily added to bpy.types."""

def main() -> None: ...
def range_str(val) -> None: ...
def rna_id_ignore(rna_id) -> None: ...
def seq_as_tuple_str(seq) -> None:
    """Format a sequence of strings as a Python tuple literal."""



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bpy.types
import mathutils

class Buffer:
    """For Python access to GPU functions requiring a pointer."""

    dimensions: typing.Any
    """ Undocumented, consider contributing."""

    def to_list(self) -> list:
        """Return the buffer as a list.

        :return: The buffer as a list.
        """

class GPUBatch:
    """Reusable container for drawable geometry."""

    def draw(self, shader: GPUShader | None | None = None) -> None:
        """Run the drawing shader with the parameters assigned to the batch.

                :param shader: Shader that performs the drawing operations.
        If None is passed, the last shader set to this batch will run.
        """

    def draw_instanced(
        self, program: GPUShader, *, instance_start: int = 0, instance_count: int = 0
    ) -> None:
        """Draw multiple instances of the drawing program with the parameters assigned
        to the batch. In the vertex shader, gl_InstanceID will contain the instance
        number being drawn.

                :param program: Program that performs the drawing operations.
                :param instance_start: Number of the first instance to draw.
                :param instance_count: Number of instances to draw. When not provided or set to 0
        the number of instances will be determined by the number of rows in the first
        vertex buffer.
        """

    def draw_range(
        self, program: GPUShader, *, elem_start: int = 0, elem_count: int = 0
    ) -> None:
        """Run the drawing program with the parameters assigned to the batch. Only draw the elem_count elements of the index buffer starting at elem_start.

                :param program: Program that performs the drawing operations.
                :param elem_start: First index to draw. When not provided or set to 0 drawing
        will start from the first element of the index buffer.
                :param elem_count: Number of elements of the index buffer to draw. When not
        provided or set to 0 all elements from elem_start to the end of the
        index buffer will be drawn.
        """

    def program_set(self, program: GPUShader) -> None:
        """Assign a shader to this batch that will be used for drawing when not overwritten later.
        Note: This method has to be called in the draw context that the batch will be drawn in.
        This function does not need to be called when you always
        set the shader when calling `gpu.types.GPUBatch.draw`.

                :param program: The program/shader the batch will use in future draw calls.
        """

    def vertbuf_add(self, buf: GPUVertBuf) -> None:
        """Add another vertex buffer to the Batch.
        It is not possible to add more vertices to the batch using this method.
        Instead it can be used to add more attributes to the existing vertices.
        A good use case would be when you have a separate
        vertex buffer for vertex positions and vertex normals.
        Current a batch can have at most GPU_BATCH_VBO_MAX_LEN vertex buffers.

                :param buf: The vertex buffer that will be added to the batch.
        """

class GPUFrameBuffer:
    """This object gives access to framebuffer functionalities.
    When a layer is specified in a argument, a single layer of a 3D or array texture is attached to the frame-buffer.
    For cube map textures, layer is translated into a cube map face.
    """

    is_bound: typing.Any
    """ Checks if this is the active frame-buffer in the context."""

    def bind(self) -> None:
        """Context manager to ensure balanced bind calls, even in the case of an error."""

    def clear(
        self,
        *,
        color: None | collections.abc.Sequence[float] | None = None,
        depth: None | float | None = None,
        stencil: None | int | None = None,
    ) -> None:
        """Fill color, depth and stencil textures with specific value.
        Common values: color=(0.0, 0.0, 0.0, 1.0), depth=1.0, stencil=0.

                :param color: Sequence of 3 or 4 floats representing (r, g, b, a).
                :param depth: depth value.
                :param stencil: stencil value.
        """

    def read_color(
        self,
        x: int,
        y: int,
        xsize: int,
        ysize: int,
        channels: int,
        slot: int,
        format: typing.Literal[
            "FLOAT", "INT", "UINT", "UBYTE", "UINT_24_8", "10_11_11_REV"
        ],
        *,
        data: Buffer | None | None = None,
    ) -> Buffer:
        """Read a block of pixels from the frame buffer.

                :param x: Lower left corner x of a rectangular block of pixels.
                :param y: Lower left corner y of a rectangular block of pixels.
                :param xsize: Width of the pixel rectangle.
                :param ysize: Height of the pixel rectangle.
                :param channels: Number of components to read.
                :param slot: The framebuffer slot to read data from.
                :param format: The format that describes the content of a single channel.
        UINT_24_8 is deprecated, use FLOAT instead.
                :param data: Optional Buffer object to fill with the pixels values.
                :return: The Buffer with the read pixels.
        """

    def read_depth(
        self,
        x: int,
        y: int,
        xsize: int,
        ysize: int,
        *,
        data: Buffer | None | None = None,
    ) -> Buffer:
        """Read a pixel depth block from the frame buffer.

        :param x: Lower left corner x of a rectangular block of pixels.
        :param y: Lower left corner y of a rectangular block of pixels.
        :param xsize: Width of the pixel rectangle.
        :param ysize: Height of the pixel rectangle.
        :param data: Optional Buffer object to fill with the pixels values.
        :return: The Buffer with the read pixels.
        """

    def viewport_get(self) -> tuple[int, int, int, int]:
        """Returns position and dimension to current viewport.

        :return: The viewport as (x, y, width, height).
        """

    def viewport_set(self, x: int, y: int, xsize: int, ysize: int) -> None:
        """Set the viewport for this framebuffer object.
        Note: The viewport state is not saved upon framebuffer rebind.

                :param x: Lower left corner x of the viewport rectangle, in pixels.
                :param y: Lower left corner y of the viewport rectangle, in pixels.
                :param xsize: Width of the viewport.
                :param ysize: Height of the viewport.
        """

class GPUIndexBuf:
    """Contains an index buffer."""

class GPUOffScreen:
    """This object gives access to off screen buffers."""

    height: int
    """ Height of the texture."""

    texture_color: GPUTexture
    """ The color texture attached."""

    width: int
    """ Width of the texture."""

    def bind(self) -> OffScreenStackContext:
        """Context manager to ensure balanced bind calls, even in the case of an error.

        :return: A context manager for the off-screen binding.
        """

    def draw_view3d(
        self,
        scene: bpy.types.Scene,
        view_layer: bpy.types.ViewLayer,
        view3d: bpy.types.SpaceView3D,
        region: bpy.types.Region,
        view_matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix,
        projection_matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix,
        *,
        do_color_management: bool = False,
        draw_background: bool = True,
    ) -> None:
        """Draw the 3d viewport in the offscreen object.

        :param scene: Scene to draw.
        :param view_layer: View layer to draw.
        :param view3d: 3D View to get the drawing settings from.
        :param region: Region of the 3D View (required as temporary draw target).
        :param view_matrix: View Matrix (e.g. camera.matrix_world.inverted()).
        :param projection_matrix: Projection Matrix (e.g. camera.calc_matrix_camera(...)).
        :param do_color_management: Color manage the output.
        :param draw_background: Draw background.
        """

    def free(self) -> None:
        """Free the offscreen object.
        The framebuffer, texture and render objects will no longer be accessible.

        """

    def unbind(self, *, restore: bool = True) -> None:
        """Unbind the offscreen object.

        :param restore: Restore the OpenGL state, can only be used when the state has been saved before.
        """

class GPUShader:
    name: str
    """ The name of the shader object for debugging purposes (read-only)."""

    program: int
    """ The name of the program object for use by the OpenGL API (read-only).
This is deprecated and will always return -1."""

    def attr_from_name(self, name: str) -> int:
        """Get attribute location by name.

        :param name: The name of the attribute variable whose location is to be queried.
        :return: The location of an attribute variable.
        """

    def attrs_info_get(self) -> tuple[tuple[str, str | None], ...]:
        """Information about the attributes used in the Shader.

        :return: tuples containing information about the attributes in order (name, type)
        """

    def bind(self) -> None:
        """Bind the shader object. Required to be able to change uniforms of this shader."""

    def format_calc(self) -> GPUVertFormat:
        """Build a new format based on the attributes of the shader.

        :return: vertex attribute format for the shader
        """

    def image(self, name: str, texture: GPUTexture) -> None:
        """Specify the value of an image variable for the current GPUShader.

        :param name: Name of the image variable to which the texture is to be bound.
        :param texture: Texture to attach.
        """

    def ssbo(self, name: str, ssbo: GPUStorageBuf) -> None:
        """Specify the value of a shader storage buffer (SSBO) variable for the current GPUShader.

        :param name: name of the SSBO variable in the shader.
        :param ssbo: Storage Buffer to attach.
        """

    def uniform_block(self, name: str, ubo: GPUUniformBuf) -> None:
        """Specify the value of a uniform buffer object variable for the current GPUShader.

        :param name: Name of the uniform variable whose UBO is to be specified.
        :param ubo: Uniform Buffer to attach.
        """

    def uniform_block_from_name(self, name: str) -> int:
        """Get uniform block location by name.

        :param name: Name of the uniform block variable whose location is to be queried.
        :return: The location of the uniform block variable.
        """

    def uniform_bool(
        self, name: str, value: bool | collections.abc.Sequence[bool]
    ) -> None:
        """Specify the value of a uniform variable for the current program object.

        :param name: Name of the uniform variable whose value is to be changed.
        :param value: Value that will be used to update the specified uniform variable.
        """

    def uniform_float(
        self, name: str, value: collections.abc.Sequence[float] | float
    ) -> None:
        """Specify the value of a uniform variable for the current program object.

        :param name: Name of the uniform variable whose value is to be changed.
        :param value: Value that will be used to update the specified uniform variable.
        """

    def uniform_from_name(self, name: str) -> int:
        """Get uniform location by name.

        :param name: Name of the uniform variable whose location is to be queried.
        :return: Location of the uniform variable.
        """

    def uniform_int(self, name: str, seq: collections.abc.Sequence[int] | int) -> None:
        """Specify the value of a uniform variable for the current program object.

        :param name: Name of the uniform variable whose value is to be changed.
        :param seq: Value that will be used to update the specified uniform variable.
        """

    def uniform_sampler(self, name: str, texture: GPUTexture) -> None:
        """Specify the value of a texture uniform variable for the current GPUShader.

        :param name: Name of the uniform variable whose texture is to be specified.
        :param texture: Texture to attach.
        """

    def uniform_vector_float(
        self,
        location: int,
        buffer: collections.abc.Sequence[float],
        length: int,
        count: int,
    ) -> None:
        """Set the buffer to fill the uniform.

                :param location: Location of the uniform variable to be modified.
                :param buffer: The data that should be set. Can support the buffer protocol.
                :param length: Size of the uniform data type:

        1: float

        2: vec2 or float[2]

        3: vec3 or float[3]

        4: vec4 or float[4]

        9: mat3

        16: mat4
                :param count: Specifies the number of elements, vector or matrices that are to be modified.
        """

    def uniform_vector_int(
        self, location: int, buffer: Buffer, length: int, count: int
    ) -> None:
        """Set the buffer to fill the uniform.

        :param location: Location of the uniform variable to be modified.
        :param buffer: Buffer object with format matching the uniform.
        :param length: Size of the uniform data type.
        :param count: Specifies the number of elements that are to be modified.
        """

class GPUShaderCreateInfo:
    """Stores and describes types and variables that are used in shader sources."""

    def compute_source(self, source: str) -> None:
        """compute shader source code written in GLSL.Example:`GLSL Cross Compilation <https://developer.blender.org/docs/features/gpu/glsl_cross_compilation/>`__

        :param source: The compute shader source code.
        """

    def define(self, name: str, value: str) -> None:
        """Add a preprocessing define directive. In GLSL it would be something like:

        :param name: Token name.
        :param value: Text that replaces token occurrences.
        """

    def depth_write(
        self, value: typing.Literal["UNCHANGED", "ANY", "GREATER", "LESS"]
    ) -> None:
        """Specify a depth write behavior when modifying gl_FragDepth.There is a common optimization for GPUs that relies on an early depth
        test to be run before the fragment shader so that the shader evaluation
        can be skipped if the fragment ends up being discarded because it is occluded.This optimization does not affect the final rendering, and is typically
        possible when the fragment does not change the depth programmatically.
        There is, however, a class of operations on the depth in the shader which
        could still be performed while allowing the early depth test to operate.This function alters the behavior of the optimization to allow those operations
        to be performed.

                :param value: Depth write value.
        :UNCHANGED: disables depth write in a fragment shader and execution of the fragments can be optimized away.
        :ANY: enables depth write in a fragment shader for any fragments
        :GREATER: enables depth write in a fragment shader for depth values that are greater than the depth value in the output buffer.
        :LESS: enables depth write in a fragment shader for depth values that are less than the depth value in the output buffer.
        """

    def fragment_out(
        self,
        slot: int,
        type: typing.Literal[
            "FLOAT",
            "VEC2",
            "VEC3",
            "VEC4",
            "MAT3",
            "MAT4",
            "UINT",
            "UVEC2",
            "UVEC3",
            "UVEC4",
            "INT",
            "IVEC2",
            "IVEC3",
            "IVEC4",
            "BOOL",
        ],
        name: str,
        *,
        blend: typing.Literal["NONE", "SRC_0", "SRC_1"] = "NONE",
    ) -> None:
        """Specify a fragment output corresponding to a framebuffer target slot.

        :param slot: The attribute index.
        :param type: The data type of the output.
        :param name: Name of the attribute.
        :param blend: Dual Source Blending Index.
        """

    def fragment_source(self, source: str) -> None:
        """Fragment shader source code written in GLSL.Example:`GLSL Cross Compilation <https://developer.blender.org/docs/features/gpu/glsl_cross_compilation/>`__

        :param source: The fragment shader source code.
        """

    def image(
        self,
        slot: int,
        format: typing.Literal[
            "RGBA8UI",
            "RGBA8I",
            "RGBA8",
            "RGBA32UI",
            "RGBA32I",
            "RGBA32F",
            "RGBA16UI",
            "RGBA16I",
            "RGBA16F",
            "RGBA16",
            "RG8UI",
            "RG8I",
            "RG8",
            "RG32UI",
            "RG32I",
            "RG32F",
            "RG16UI",
            "RG16I",
            "RG16F",
            "RG16",
            "R8UI",
            "R8I",
            "R8",
            "R32UI",
            "R32I",
            "R32F",
            "R16UI",
            "R16I",
            "R16F",
            "R16",
            "R11F_G11F_B10F",
            "DEPTH32F_STENCIL8",
            "DEPTH24_STENCIL8",
            "SRGB8_A8",
            "RGB16F",
            "SRGB8_A8_DXT1",
            "SRGB8_A8_DXT3",
            "SRGB8_A8_DXT5",
            "RGBA8_DXT1",
            "RGBA8_DXT3",
            "RGBA8_DXT5",
            "DEPTH_COMPONENT32F",
            "DEPTH_COMPONENT24",
            "DEPTH_COMPONENT16",
        ],
        type: typing.Literal[
            "FLOAT_BUFFER",
            "FLOAT_1D",
            "FLOAT_1D_ARRAY",
            "FLOAT_2D",
            "FLOAT_2D_ARRAY",
            "FLOAT_3D",
            "FLOAT_CUBE",
            "FLOAT_CUBE_ARRAY",
            "INT_BUFFER",
            "INT_1D",
            "INT_1D_ARRAY",
            "INT_2D",
            "INT_2D_ARRAY",
            "INT_3D",
            "INT_CUBE",
            "INT_CUBE_ARRAY",
            "UINT_BUFFER",
            "UINT_1D",
            "UINT_1D_ARRAY",
            "UINT_2D",
            "UINT_2D_ARRAY",
            "UINT_3D",
            "UINT_CUBE",
            "UINT_CUBE_ARRAY",
            "SHADOW_2D",
            "SHADOW_2D_ARRAY",
            "SHADOW_CUBE",
            "SHADOW_CUBE_ARRAY",
            "DEPTH_2D",
            "DEPTH_2D_ARRAY",
            "DEPTH_CUBE",
            "DEPTH_CUBE_ARRAY",
        ],
        name: str,
        *,
        qualifiers: set[typing.Literal["NO_RESTRICT", "READ", "WRITE"]] = {
            "NO_RESTRICT"
        },
    ) -> None:
        """Specify an image resource used for arbitrary load and store operations.

        :param slot: The image resource index.
        :param format: The GPUTexture format that is passed to the shader.
        :param type: The data type describing how the image is to be read in the shader.
        :param name: The image resource name.
        :param qualifiers: Set containing values that describe how the image resource is to be read or written.
        """

    def local_group_size(self, x: int, y: int = 1, z: int = 1) -> None:
        """Specify the local group size for compute shaders.

        :param x: The local group size in the x dimension.
        :param y: The local group size in the y dimension. Optional. Defaults to 1.
        :param z: The local group size in the z dimension. Optional. Defaults to 1.
        """

    def push_constant(
        self,
        type: typing.Literal[
            "FLOAT",
            "VEC2",
            "VEC3",
            "VEC4",
            "MAT3",
            "MAT4",
            "UINT",
            "UVEC2",
            "UVEC3",
            "UVEC4",
            "INT",
            "IVEC2",
            "IVEC3",
            "IVEC4",
            "BOOL",
        ],
        name: str,
        size: int = 0,
    ) -> None:
        """Specify a global access constant.

        :param type: The data type of the constant.
        :param name: Name of the constant.
        :param size: If not zero, indicates that the constant is an array with the specified size.
        """

    def sampler(
        self,
        slot: int,
        type: typing.Literal[
            "FLOAT_BUFFER",
            "FLOAT_1D",
            "FLOAT_1D_ARRAY",
            "FLOAT_2D",
            "FLOAT_2D_ARRAY",
            "FLOAT_3D",
            "FLOAT_CUBE",
            "FLOAT_CUBE_ARRAY",
            "INT_BUFFER",
            "INT_1D",
            "INT_1D_ARRAY",
            "INT_2D",
            "INT_2D_ARRAY",
            "INT_3D",
            "INT_CUBE",
            "INT_CUBE_ARRAY",
            "UINT_BUFFER",
            "UINT_1D",
            "UINT_1D_ARRAY",
            "UINT_2D",
            "UINT_2D_ARRAY",
            "UINT_3D",
            "UINT_CUBE",
            "UINT_CUBE_ARRAY",
            "SHADOW_2D",
            "SHADOW_2D_ARRAY",
            "SHADOW_CUBE",
            "SHADOW_CUBE_ARRAY",
            "DEPTH_2D",
            "DEPTH_2D_ARRAY",
            "DEPTH_CUBE",
            "DEPTH_CUBE_ARRAY",
        ],
        name: str,
    ) -> None:
        """Specify an image texture sampler.

        :param slot: The image texture sampler index.
        :param type: The data type describing the format of each sampler unit.
        :param name: The image texture sampler name.
        """

    def storage_buf(
        self,
        slot: int,
        type_name: str,
        name: str,
        *,
        qualifiers: set[typing.Literal["NO_RESTRICT", "READ", "WRITE"]] = {
            "NO_RESTRICT"
        },
    ) -> None:
        """Specify a storage buffer (shader storage buffer object).

                :param slot: The storage buffer index.
                :param type_name: Name of the data type. It can be a struct type defined in the
        source passed through `gpu.types.GPUShaderCreateInfo.typedef_source`.
                :param name: The storage buffer variable name.
                :param qualifiers: Set containing values that describe how the ssbo is to be read or written.
        """

    def typedef_source(self, source: str) -> None:
        """Source code included before resource declaration. Useful for defining structs used by Uniform Buffers.Example:

        :param source: The source code defining types.
        """

    def uniform_buf(self, slot: int, type_name: str, name: str) -> None:
        """Specify a uniform variable whose type can be one of those declared in `gpu.types.GPUShaderCreateInfo.typedef_source`.

        :param slot: The uniform variable index.
        :param type_name: Name of the data type. It can be a struct type defined in the source passed through the `gpu.types.GPUShaderCreateInfo.typedef_source`.
        :param name: The uniform variable name.
        """

    def vertex_in(
        self,
        slot: int,
        type: typing.Literal[
            "FLOAT",
            "VEC2",
            "VEC3",
            "VEC4",
            "MAT3",
            "MAT4",
            "UINT",
            "UVEC2",
            "UVEC3",
            "UVEC4",
            "INT",
            "IVEC2",
            "IVEC3",
            "IVEC4",
            "BOOL",
        ],
        name: str,
    ) -> None:
        """Add a vertex shader input attribute.

        :param slot: The attribute index.
        :param type: The data type of the attribute.
        :param name: name of the attribute.
        """

    def vertex_out(self, interface: GPUStageInterfaceInfo) -> None:
        """Add a vertex shader output interface block.

        :param interface: Object describing the block.
        """

    def vertex_source(self, source: str) -> None:
        """Vertex shader source code written in GLSL.Example:`GLSL Cross Compilation <https://developer.blender.org/docs/features/gpu/glsl_cross_compilation/>`__

        :param source: The vertex shader source code.
        """

class GPUStageInterfaceInfo:
    """List of varyings between shader stages."""

    name: str
    """ Name of the interface block."""

    def flat(
        self,
        type: typing.Literal[
            "FLOAT",
            "VEC2",
            "VEC3",
            "VEC4",
            "MAT3",
            "MAT4",
            "UINT",
            "UVEC2",
            "UVEC3",
            "UVEC4",
            "INT",
            "IVEC2",
            "IVEC3",
            "IVEC4",
            "BOOL",
        ],
        name: str,
    ) -> None:
        """Add an attribute with qualifier of type flat to the interface block.

        :param type: The data type of the attribute.
        :param name: name of the attribute.
        """

    def no_perspective(
        self,
        type: typing.Literal[
            "FLOAT",
            "VEC2",
            "VEC3",
            "VEC4",
            "MAT3",
            "MAT4",
            "UINT",
            "UVEC2",
            "UVEC3",
            "UVEC4",
            "INT",
            "IVEC2",
            "IVEC3",
            "IVEC4",
            "BOOL",
        ],
        name: str,
    ) -> None:
        """Add an attribute with qualifier of type no_perspective to the interface block.

        :param type: The data type of the attribute.
        :param name: name of the attribute.
        """

    def smooth(
        self,
        type: typing.Literal[
            "FLOAT",
            "VEC2",
            "VEC3",
            "VEC4",
            "MAT3",
            "MAT4",
            "UINT",
            "UVEC2",
            "UVEC3",
            "UVEC4",
            "INT",
            "IVEC2",
            "IVEC3",
            "IVEC4",
            "BOOL",
        ],
        name: str,
    ) -> None:
        """Add an attribute with qualifier of type smooth to the interface block.

        :param type: The data type of the attribute.
        :param name: name of the attribute.
        """

class GPUStorageBuf:
    """This object gives access to GPU storage buffers (SSBO)."""

    def read(self) -> None:
        """Read the full contents of the storage buffer and return a bytes object.
        Slow! Only use for inspection / debugging.

        """

    def update(self, data) -> None:
        """Update the data of the storage buffer object.
        Data length will be padded to vec4 (16 bytes) if needed.

                :param data:
        """

class GPUTexture:
    """This object gives access to GPU textures."""

    format: str
    """ Format of the texture."""

    height: int
    """ Height of the texture."""

    width: int
    """ Width of the texture."""

    def anisotropic_filter(self, use_anisotropic: bool) -> None:
        """Set anisotropic filter usage. This only has effect if mipmapping is enabled.

        :param use_anisotropic: If set to true, the texture will use anisotropic filtering.
        """

    def clear(
        self,
        format: typing.Literal[
            "FLOAT", "INT", "UINT", "UBYTE", "UINT_24_8", "10_11_11_REV"
        ] = "FLOAT",
        value: collections.abc.Sequence[float] | collections.abc.Sequence[int] = (
            0.0,
            0.0,
            0.0,
            1.0,
        ),
    ) -> None:
        """Fill texture with specific value.

                :param format: The format that describes the content of a single item.
        UINT_24_8 is deprecated, use FLOAT instead.
                :param value: Sequence each representing the value to fill. Sizes 1..4 are supported.
        """

    def extend_mode(
        self,
        extend_mode: typing.Literal[
            "EXTEND", "REPEAT", "MIRRORED_REPEAT", "CLAMP_TO_BORDER"
        ] = "EXTEND",
        /,
    ) -> None:
        """Set texture sampling method for coordinates outside of the [0..1] uv range along
        both the x and y axis.

                :param extend_mode: the specified extent mode.
        """

    def extend_mode_x(
        self,
        extend_mode: typing.Literal[
            "EXTEND", "REPEAT", "MIRRORED_REPEAT", "CLAMP_TO_BORDER"
        ] = "EXTEND",
        /,
    ) -> None:
        """Set texture sampling method for coordinates outside of the [0..1] uv range along the x axis.

        :param extend_mode: the specified extent mode.
        """

    def extend_mode_y(
        self,
        extend_mode: typing.Literal[
            "EXTEND", "REPEAT", "MIRRORED_REPEAT", "CLAMP_TO_BORDER"
        ] = "EXTEND",
        /,
    ) -> None:
        """Set texture sampling method for coordinates outside of the [0..1] uv range along the y axis.

        :param extend_mode: the specified extent mode.
        """

    def filter_mode(self, use_filter: bool) -> None:
        """Set texture filter usage.

        :param use_filter: If set to true, the texture will use linear interpolation between neighboring texels.
        """

    def mipmap_mode(self, use_mipmap: bool = True, use_filter: bool = True) -> None:
        """Set texture filter and mip-map usage.

        :param use_mipmap: If set to true, the texture will use mip-mapping as anti-aliasing method.
        :param use_filter: If set to true, the texture will use linear interpolation between neighboring texels.
        """

    def read(self) -> Buffer:
        """Creates a buffer with the value of all pixels.

        :return: The Buffer with the read pixels.
        """

    def update(
        self,
        format: typing.Literal[
            "FLOAT", "INT", "UINT", "UBYTE", "UINT_24_8", "10_11_11_REV"
        ],
        data: Buffer,
    ) -> None:
        """Update the entire texture with new pixel data.

        :param format: The data format of the pixel data.
        :param data: Buffer with pixel data the size of the whole texture.
        """

class GPUUniformBuf:
    """This object gives access to uniform buffers."""

    def update(self, data: Buffer) -> None:
        """Update the data of the uniform buffer object.

        :param data: Data to fill the buffer.
        """

class GPUVertBuf:
    """Contains a VBO."""

    def attr_fill(
        self,
        id: int | str,
        data: Buffer
        | collections.abc.Sequence[collections.abc.Sequence[float]]
        | collections.abc.Sequence[collections.abc.Sequence[int]]
        | collections.abc.Sequence[float]
        | collections.abc.Sequence[int],
    ) -> None:
        """Insert data into the buffer for a single attribute.

        :param id: Either the name or the id of the attribute.
        :param data: Buffer or sequence of data that should be stored in the buffer
        """

class GPUVertFormat:
    """This object contains information about the structure of a vertex buffer."""

    def attr_add(
        self,
        id: str,
        comp_type: typing.Literal["I8", "U8", "I16", "U16", "I32", "U32", "F32", "I10"],
        len: int,
        fetch_mode: typing.Literal["FLOAT", "INT", "INT_TO_FLOAT_UNIT"],
    ) -> None:
        """Add a new attribute to the format.

                :param id: Name of the attribute. Often position, normal, ...
                :param comp_type: The data type that will be used to store the value in memory.
                :param len: How many individual values the attribute consists of
        (e.g. 2 for uv coordinates).
                :param fetch_mode: How values from memory will be converted when used in the shader.
        This is mainly useful for memory optimizations when you want to store values with
        reduced precision. E.g. you can store a float in only 1 byte but it will be
        converted to a normal 4 byte float when used.
        """

class MatrixStackContext:
    """Context manager for matrix stack push/pop."""

class OffScreenStackContext:
    """Context manager for off-screen framebuffer binding."""



import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import _bpy_types
import bl_ui.utils
import bpy.types
import rna_prop_ui

class STRIP_PT_adjust_color(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_adjust_comp(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_adjust_crop(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_adjust_sound(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_adjust_transform(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_adjust_video(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_color_tag_picker(StripColorTagPicker, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, _context) -> None:
        """

        :param _context:
        """

class STRIP_PT_custom_props(
    rna_prop_ui.PropertyPanel, StripButtonsPanel, _bpy_types.Panel
):
    """The subclass should have its own poll function
    and the variable _context_path MUST be set.
    """

    COMPAT_ENGINES: typing.Any
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_order: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

class STRIP_PT_effect(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    def draw_header_preset(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_effect_text_box(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    bl_translation_context: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    def draw_header(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_effect_text_layout(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_effect_text_outline(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    def draw_header(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_effect_text_shadow(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    def draw_header(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_effect_text_style(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_parent_id: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_effect_text_style_presets(bl_ui.utils.PresetPanel, _bpy_types.Panel):
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any
    preset_add_operator: typing.Any
    preset_operator: typing.Any
    preset_subdir: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

class STRIP_PT_mask(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_movie_clip(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_scene(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_scene_sound(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_source(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class STRIP_PT_strip(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_options: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

class STRIP_PT_time(StripButtonsPanel, _bpy_types.Panel):
    bl_context: typing.Any
    bl_label: typing.Any
    bl_region_type: typing.Any
    bl_rna: typing.Any
    bl_space_type: typing.Any
    id_data: typing.Any

    def bl_rna_get_subclass(self) -> bpy.types.Struct:
        """

        :return: The RNA type or default when not found.
        """

    def bl_rna_get_subclass_py(self) -> typing.Any:
        """

        :return: The class or default when not found.
        """

    def draw(self, context) -> None:
        """

        :param context:
        """

    def draw_header_preset(self, context) -> None:
        """

        :param context:
        """

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class StripButtonsPanel:
    bl_context: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """

class StripColorTagPicker:
    bl_context: typing.Any
    bl_region_type: typing.Any
    bl_space_type: typing.Any

    @classmethod
    def poll(cls, context) -> None:
        """

        :param context:
        """
